;**************************************
;** store window sizes & positions
;
;   usage: 
;      to save window sizes & positions, call "WinSave.ahk"
;      to restore window sizes & positions, call "WinRestore.ahk"
;
;   incorporates code from "expose.ahk" by "keyboardfreak"
;      http://www.autohotkey.com/forum/topic1090.html
;
; @version 1.0 cranky 20-Mar-2010; tested on Win XP SP2
;**************************************

#SingleInstance force

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
#Warn  ; Recommended for catching common errors.
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.

;SetTitleMatchMode:
;  1 = starts with
;  2 = contains 
;  3 = exact
SetTitleMatchMode, 2

; global variables
NumWindows = 0
active_window = 0

; global constants
spaces  := "                 "
movetime = 700 ; time for a window to resize / minimize / maximize

;**********************************
;** store window sizes & positions; 
;   shrink to fit a small screen 
;**********************************

BlockInput, On

datafile = %A_Temp%\$winsave$.tmp
If FileExist(datafile)
	FileDelete, %datafile%

msg := "# temp file for WinSave.ahk and WinRestore.ahk" . Chr(13) . Chr(10)
FileAppend, %msg%, %datafile%

;** enumerate all windows with titles:
;
WinGet, IDs, List, , , Program Manager
Loop, %IDs%
{
	StringTrimRight, id, IDs%a_index%, 0
	WinGetTitle, title, ahk_id %id%

	; don't add windows with empty titles
	If title =
		Continue

	numwindows += 1

	; store the index of the active window
	IfWinActive, ahk_id %id%
		active_window = %id%

	WinGet, IsMinMax, MinMax, ahk_id %id%
	If IsMinMax <> 0
	{
		WinRestore, ahk_id %id%
		Sleep, %movetime%
	}

	WinGetPos, x, y, wid, hgt, ahk_id %id%

	; store window id, position & size as a formatted string:
	fields = %id%#%IsMinMax%#%x%#%y%#%wid%#%hgt%

	fields := fields . Chr(13) . Chr(10)
	FileAppend, %fields%, %datafile%

	If (IsMinMax < 0)
	{
		WinMinimize, ahk_id %id%
		Sleep, %movetime%
	}
	Else If (IsMinMax > 0)
	{
		WinMaximize, ahk_id %id%
		Sleep, %movetime%
	}
}

If active_window <> 0
	WinActivate, ahk_id %active_window%

BlockInput, Off
Exit ;
